# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/errors.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import policy_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2
from google.ads.google_ads.v2.proto.common import value_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_value__pb2
from google.ads.google_ads.v2.proto.errors import access_invitation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_access__invitation__error__pb2
from google.ads.google_ads.v2.proto.errors import account_budget_proposal_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_account__budget__proposal__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_customizer_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__customizer__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_group_ad_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__ad__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_group_bid_modifier_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__bid__modifier__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_group_criterion_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__criterion__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_group_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_group_feed_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__feed__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_parameter_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__parameter__error__pb2
from google.ads.google_ads.v2.proto.errors import ad_sharing_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__sharing__error__pb2
from google.ads.google_ads.v2.proto.errors import adx_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_adx__error__pb2
from google.ads.google_ads.v2.proto.errors import asset_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_asset__error__pb2
from google.ads.google_ads.v2.proto.errors import authentication_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_authentication__error__pb2
from google.ads.google_ads.v2.proto.errors import authorization_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_authorization__error__pb2
from google.ads.google_ads.v2.proto.errors import bidding_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_bidding__error__pb2
from google.ads.google_ads.v2.proto.errors import bidding_strategy_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_bidding__strategy__error__pb2
from google.ads.google_ads.v2.proto.errors import billing_setup_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_billing__setup__error__pb2
from google.ads.google_ads.v2.proto.errors import campaign_budget_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__budget__error__pb2
from google.ads.google_ads.v2.proto.errors import campaign_criterion_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__criterion__error__pb2
from google.ads.google_ads.v2.proto.errors import campaign_draft_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__draft__error__pb2
from google.ads.google_ads.v2.proto.errors import campaign_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__error__pb2
from google.ads.google_ads.v2.proto.errors import campaign_experiment_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__experiment__error__pb2
from google.ads.google_ads.v2.proto.errors import campaign_feed_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__feed__error__pb2
from google.ads.google_ads.v2.proto.errors import campaign_shared_set_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__shared__set__error__pb2
from google.ads.google_ads.v2.proto.errors import change_status_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_change__status__error__pb2
from google.ads.google_ads.v2.proto.errors import collection_size_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_collection__size__error__pb2
from google.ads.google_ads.v2.proto.errors import context_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_context__error__pb2
from google.ads.google_ads.v2.proto.errors import conversion_action_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__action__error__pb2
from google.ads.google_ads.v2.proto.errors import conversion_adjustment_upload_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__adjustment__upload__error__pb2
from google.ads.google_ads.v2.proto.errors import conversion_upload_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__upload__error__pb2
from google.ads.google_ads.v2.proto.errors import country_code_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_country__code__error__pb2
from google.ads.google_ads.v2.proto.errors import criterion_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_criterion__error__pb2
from google.ads.google_ads.v2.proto.errors import currency_code_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_currency__code__error__pb2
from google.ads.google_ads.v2.proto.errors import custom_interest_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_custom__interest__error__pb2
from google.ads.google_ads.v2.proto.errors import customer_client_link_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__client__link__error__pb2
from google.ads.google_ads.v2.proto.errors import customer_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__error__pb2
from google.ads.google_ads.v2.proto.errors import customer_feed_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__feed__error__pb2
from google.ads.google_ads.v2.proto.errors import customer_manager_link_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__manager__link__error__pb2
from google.ads.google_ads.v2.proto.errors import database_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_database__error__pb2
from google.ads.google_ads.v2.proto.errors import date_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_date__error__pb2
from google.ads.google_ads.v2.proto.errors import date_range_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_date__range__error__pb2
from google.ads.google_ads.v2.proto.errors import distinct_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_distinct__error__pb2
from google.ads.google_ads.v2.proto.errors import enum_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_enum__error__pb2
from google.ads.google_ads.v2.proto.errors import extension_feed_item_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_extension__feed__item__error__pb2
from google.ads.google_ads.v2.proto.errors import extension_setting_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_extension__setting__error__pb2
from google.ads.google_ads.v2.proto.errors import feed_attribute_reference_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__attribute__reference__error__pb2
from google.ads.google_ads.v2.proto.errors import feed_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__error__pb2
from google.ads.google_ads.v2.proto.errors import feed_item_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__error__pb2
from google.ads.google_ads.v2.proto.errors import feed_item_target_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__target__error__pb2
from google.ads.google_ads.v2.proto.errors import feed_item_validation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2
from google.ads.google_ads.v2.proto.errors import feed_mapping_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__mapping__error__pb2
from google.ads.google_ads.v2.proto.errors import field_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_field__error__pb2
from google.ads.google_ads.v2.proto.errors import field_mask_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_field__mask__error__pb2
from google.ads.google_ads.v2.proto.errors import function_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_function__error__pb2
from google.ads.google_ads.v2.proto.errors import function_parsing_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_function__parsing__error__pb2
from google.ads.google_ads.v2.proto.errors import geo_target_constant_suggestion_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_geo__target__constant__suggestion__error__pb2
from google.ads.google_ads.v2.proto.errors import header_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_header__error__pb2
from google.ads.google_ads.v2.proto.errors import id_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_id__error__pb2
from google.ads.google_ads.v2.proto.errors import image_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_image__error__pb2
from google.ads.google_ads.v2.proto.errors import internal_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_internal__error__pb2
from google.ads.google_ads.v2.proto.errors import invoice_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_invoice__error__pb2
from google.ads.google_ads.v2.proto.errors import keyword_plan_ad_group_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__ad__group__error__pb2
from google.ads.google_ads.v2.proto.errors import keyword_plan_campaign_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__campaign__error__pb2
from google.ads.google_ads.v2.proto.errors import keyword_plan_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__error__pb2
from google.ads.google_ads.v2.proto.errors import keyword_plan_idea_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__idea__error__pb2
from google.ads.google_ads.v2.proto.errors import keyword_plan_keyword_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__keyword__error__pb2
from google.ads.google_ads.v2.proto.errors import keyword_plan_negative_keyword_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__negative__keyword__error__pb2
from google.ads.google_ads.v2.proto.errors import label_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_label__error__pb2
from google.ads.google_ads.v2.proto.errors import language_code_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_language__code__error__pb2
from google.ads.google_ads.v2.proto.errors import list_operation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_list__operation__error__pb2
from google.ads.google_ads.v2.proto.errors import manager_link_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_manager__link__error__pb2
from google.ads.google_ads.v2.proto.errors import media_bundle_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__bundle__error__pb2
from google.ads.google_ads.v2.proto.errors import media_file_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__file__error__pb2
from google.ads.google_ads.v2.proto.errors import media_upload_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__upload__error__pb2
from google.ads.google_ads.v2.proto.errors import multiplier_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_multiplier__error__pb2
from google.ads.google_ads.v2.proto.errors import mutate_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_mutate__error__pb2
from google.ads.google_ads.v2.proto.errors import mutate_job_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_mutate__job__error__pb2
from google.ads.google_ads.v2.proto.errors import new_resource_creation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_new__resource__creation__error__pb2
from google.ads.google_ads.v2.proto.errors import not_empty_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_not__empty__error__pb2
from google.ads.google_ads.v2.proto.errors import not_whitelisted_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_not__whitelisted__error__pb2
from google.ads.google_ads.v2.proto.errors import null_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_null__error__pb2
from google.ads.google_ads.v2.proto.errors import operation_access_denied_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_operation__access__denied__error__pb2
from google.ads.google_ads.v2.proto.errors import operator_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_operator__error__pb2
from google.ads.google_ads.v2.proto.errors import partial_failure_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_partial__failure__error__pb2
from google.ads.google_ads.v2.proto.errors import policy_finding_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__finding__error__pb2
from google.ads.google_ads.v2.proto.errors import policy_validation_parameter_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__validation__parameter__error__pb2
from google.ads.google_ads.v2.proto.errors import policy_violation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__violation__error__pb2
from google.ads.google_ads.v2.proto.errors import query_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_query__error__pb2
from google.ads.google_ads.v2.proto.errors import quota_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_quota__error__pb2
from google.ads.google_ads.v2.proto.errors import range_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_range__error__pb2
from google.ads.google_ads.v2.proto.errors import reach_plan_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_reach__plan__error__pb2
from google.ads.google_ads.v2.proto.errors import recommendation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_recommendation__error__pb2
from google.ads.google_ads.v2.proto.errors import region_code_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_region__code__error__pb2
from google.ads.google_ads.v2.proto.errors import request_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_request__error__pb2
from google.ads.google_ads.v2.proto.errors import resource_access_denied_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_resource__access__denied__error__pb2
from google.ads.google_ads.v2.proto.errors import resource_count_limit_exceeded_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_resource__count__limit__exceeded__error__pb2
from google.ads.google_ads.v2.proto.errors import setting_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_setting__error__pb2
from google.ads.google_ads.v2.proto.errors import shared_criterion_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_shared__criterion__error__pb2
from google.ads.google_ads.v2.proto.errors import shared_set_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_shared__set__error__pb2
from google.ads.google_ads.v2.proto.errors import size_limit_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_size__limit__error__pb2
from google.ads.google_ads.v2.proto.errors import string_format_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_string__format__error__pb2
from google.ads.google_ads.v2.proto.errors import string_length_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_string__length__error__pb2
from google.ads.google_ads.v2.proto.errors import url_field_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_url__field__error__pb2
from google.ads.google_ads.v2.proto.errors import user_list_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_user__list__error__pb2
from google.ads.google_ads.v2.proto.errors import youtube_video_registration_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_youtube__video__registration__error__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/errors.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\013ErrorsProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n1google/ads/googleads_v2/proto/errors/errors.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x31google/ads/googleads_v2/proto/common/policy.proto\x1a\x30google/ads/googleads_v2/proto/common/value.proto\x1a\x42google/ads/googleads_v2/proto/errors/access_invitation_error.proto\x1aHgoogle/ads/googleads_v2/proto/errors/account_budget_proposal_error.proto\x1a>google/ads/googleads_v2/proto/errors/ad_customizer_error.proto\x1a\x33google/ads/googleads_v2/proto/errors/ad_error.proto\x1a<google/ads/googleads_v2/proto/errors/ad_group_ad_error.proto\x1a\x46google/ads/googleads_v2/proto/errors/ad_group_bid_modifier_error.proto\x1a\x43google/ads/googleads_v2/proto/errors/ad_group_criterion_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/ad_group_error.proto\x1a>google/ads/googleads_v2/proto/errors/ad_group_feed_error.proto\x1a=google/ads/googleads_v2/proto/errors/ad_parameter_error.proto\x1a;google/ads/googleads_v2/proto/errors/ad_sharing_error.proto\x1a\x34google/ads/googleads_v2/proto/errors/adx_error.proto\x1a\x36google/ads/googleads_v2/proto/errors/asset_error.proto\x1a?google/ads/googleads_v2/proto/errors/authentication_error.proto\x1a>google/ads/googleads_v2/proto/errors/authorization_error.proto\x1a\x38google/ads/googleads_v2/proto/errors/bidding_error.proto\x1a\x41google/ads/googleads_v2/proto/errors/bidding_strategy_error.proto\x1a>google/ads/googleads_v2/proto/errors/billing_setup_error.proto\x1a@google/ads/googleads_v2/proto/errors/campaign_budget_error.proto\x1a\x43google/ads/googleads_v2/proto/errors/campaign_criterion_error.proto\x1a?google/ads/googleads_v2/proto/errors/campaign_draft_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/campaign_error.proto\x1a\x44google/ads/googleads_v2/proto/errors/campaign_experiment_error.proto\x1a>google/ads/googleads_v2/proto/errors/campaign_feed_error.proto\x1a\x44google/ads/googleads_v2/proto/errors/campaign_shared_set_error.proto\x1a>google/ads/googleads_v2/proto/errors/change_status_error.proto\x1a@google/ads/googleads_v2/proto/errors/collection_size_error.proto\x1a\x38google/ads/googleads_v2/proto/errors/context_error.proto\x1a\x42google/ads/googleads_v2/proto/errors/conversion_action_error.proto\x1aMgoogle/ads/googleads_v2/proto/errors/conversion_adjustment_upload_error.proto\x1a\x42google/ads/googleads_v2/proto/errors/conversion_upload_error.proto\x1a=google/ads/googleads_v2/proto/errors/country_code_error.proto\x1a:google/ads/googleads_v2/proto/errors/criterion_error.proto\x1a>google/ads/googleads_v2/proto/errors/currency_code_error.proto\x1a@google/ads/googleads_v2/proto/errors/custom_interest_error.proto\x1a\x45google/ads/googleads_v2/proto/errors/customer_client_link_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/customer_error.proto\x1a>google/ads/googleads_v2/proto/errors/customer_feed_error.proto\x1a\x46google/ads/googleads_v2/proto/errors/customer_manager_link_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/database_error.proto\x1a\x35google/ads/googleads_v2/proto/errors/date_error.proto\x1a;google/ads/googleads_v2/proto/errors/date_range_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/distinct_error.proto\x1a\x35google/ads/googleads_v2/proto/errors/enum_error.proto\x1a\x44google/ads/googleads_v2/proto/errors/extension_feed_item_error.proto\x1a\x42google/ads/googleads_v2/proto/errors/extension_setting_error.proto\x1aIgoogle/ads/googleads_v2/proto/errors/feed_attribute_reference_error.proto\x1a\x35google/ads/googleads_v2/proto/errors/feed_error.proto\x1a:google/ads/googleads_v2/proto/errors/feed_item_error.proto\x1a\x41google/ads/googleads_v2/proto/errors/feed_item_target_error.proto\x1a\x45google/ads/googleads_v2/proto/errors/feed_item_validation_error.proto\x1a=google/ads/googleads_v2/proto/errors/feed_mapping_error.proto\x1a\x36google/ads/googleads_v2/proto/errors/field_error.proto\x1a;google/ads/googleads_v2/proto/errors/field_mask_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/function_error.proto\x1a\x41google/ads/googleads_v2/proto/errors/function_parsing_error.proto\x1aOgoogle/ads/googleads_v2/proto/errors/geo_target_constant_suggestion_error.proto\x1a\x37google/ads/googleads_v2/proto/errors/header_error.proto\x1a\x33google/ads/googleads_v2/proto/errors/id_error.proto\x1a\x36google/ads/googleads_v2/proto/errors/image_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/internal_error.proto\x1a\x38google/ads/googleads_v2/proto/errors/invoice_error.proto\x1a\x46google/ads/googleads_v2/proto/errors/keyword_plan_ad_group_error.proto\x1a\x46google/ads/googleads_v2/proto/errors/keyword_plan_campaign_error.proto\x1a=google/ads/googleads_v2/proto/errors/keyword_plan_error.proto\x1a\x42google/ads/googleads_v2/proto/errors/keyword_plan_idea_error.proto\x1a\x45google/ads/googleads_v2/proto/errors/keyword_plan_keyword_error.proto\x1aNgoogle/ads/googleads_v2/proto/errors/keyword_plan_negative_keyword_error.proto\x1a\x36google/ads/googleads_v2/proto/errors/label_error.proto\x1a>google/ads/googleads_v2/proto/errors/language_code_error.proto\x1a?google/ads/googleads_v2/proto/errors/list_operation_error.proto\x1a=google/ads/googleads_v2/proto/errors/manager_link_error.proto\x1a=google/ads/googleads_v2/proto/errors/media_bundle_error.proto\x1a;google/ads/googleads_v2/proto/errors/media_file_error.proto\x1a=google/ads/googleads_v2/proto/errors/media_upload_error.proto\x1a;google/ads/googleads_v2/proto/errors/multiplier_error.proto\x1a\x37google/ads/googleads_v2/proto/errors/mutate_error.proto\x1a;google/ads/googleads_v2/proto/errors/mutate_job_error.proto\x1a\x46google/ads/googleads_v2/proto/errors/new_resource_creation_error.proto\x1a:google/ads/googleads_v2/proto/errors/not_empty_error.proto\x1a@google/ads/googleads_v2/proto/errors/not_whitelisted_error.proto\x1a\x35google/ads/googleads_v2/proto/errors/null_error.proto\x1aHgoogle/ads/googleads_v2/proto/errors/operation_access_denied_error.proto\x1a\x39google/ads/googleads_v2/proto/errors/operator_error.proto\x1a@google/ads/googleads_v2/proto/errors/partial_failure_error.proto\x1a?google/ads/googleads_v2/proto/errors/policy_finding_error.proto\x1aLgoogle/ads/googleads_v2/proto/errors/policy_validation_parameter_error.proto\x1a\x41google/ads/googleads_v2/proto/errors/policy_violation_error.proto\x1a\x36google/ads/googleads_v2/proto/errors/query_error.proto\x1a\x36google/ads/googleads_v2/proto/errors/quota_error.proto\x1a\x36google/ads/googleads_v2/proto/errors/range_error.proto\x1a;google/ads/googleads_v2/proto/errors/reach_plan_error.proto\x1a?google/ads/googleads_v2/proto/errors/recommendation_error.proto\x1a<google/ads/googleads_v2/proto/errors/region_code_error.proto\x1a\x38google/ads/googleads_v2/proto/errors/request_error.proto\x1aGgoogle/ads/googleads_v2/proto/errors/resource_access_denied_error.proto\x1aNgoogle/ads/googleads_v2/proto/errors/resource_count_limit_exceeded_error.proto\x1a\x38google/ads/googleads_v2/proto/errors/setting_error.proto\x1a\x41google/ads/googleads_v2/proto/errors/shared_criterion_error.proto\x1a;google/ads/googleads_v2/proto/errors/shared_set_error.proto\x1a;google/ads/googleads_v2/proto/errors/size_limit_error.proto\x1a>google/ads/googleads_v2/proto/errors/string_format_error.proto\x1a>google/ads/googleads_v2/proto/errors/string_length_error.proto\x1a:google/ads/googleads_v2/proto/errors/url_field_error.proto\x1a:google/ads/googleads_v2/proto/errors/user_list_error.proto\x1aKgoogle/ads/googleads_v2/proto/errors/youtube_video_registration_error.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"R\n\x10GoogleAdsFailure\x12>\n\x06\x65rrors\x18\x01 \x03(\x0b\x32..google.ads.googleads.v2.errors.GoogleAdsError\"\x98\x02\n\x0eGoogleAdsError\x12=\n\nerror_code\x18\x01 \x01(\x0b\x32).google.ads.googleads.v2.errors.ErrorCode\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x36\n\x07trigger\x18\x03 \x01(\x0b\x32%.google.ads.googleads.v2.common.Value\x12?\n\x08location\x18\x04 \x01(\x0b\x32-.google.ads.googleads.v2.errors.ErrorLocation\x12=\n\x07\x64\x65tails\x18\x05 \x01(\x0b\x32,.google.ads.googleads.v2.errors.ErrorDetails\"\xc4V\n\tErrorCode\x12V\n\rrequest_error\x18\x01 \x01(\x0e\x32=.google.ads.googleads.v2.errors.RequestErrorEnum.RequestErrorH\x00\x12o\n\x16\x62idding_strategy_error\x18\x02 \x01(\x0e\x32M.google.ads.googleads.v2.errors.BiddingStrategyErrorEnum.BiddingStrategyErrorH\x00\x12Z\n\x0furl_field_error\x18\x03 \x01(\x0e\x32?.google.ads.googleads.v2.errors.UrlFieldErrorEnum.UrlFieldErrorH\x00\x12i\n\x14list_operation_error\x18\x04 \x01(\x0e\x32I.google.ads.googleads.v2.errors.ListOperationErrorEnum.ListOperationErrorH\x00\x12P\n\x0bquery_error\x18\x05 \x01(\x0e\x32\x39.google.ads.googleads.v2.errors.QueryErrorEnum.QueryErrorH\x00\x12S\n\x0cmutate_error\x18\x07 \x01(\x0e\x32;.google.ads.googleads.v2.errors.MutateErrorEnum.MutateErrorH\x00\x12]\n\x10\x66ield_mask_error\x18\x08 \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.FieldMaskErrorEnum.FieldMaskErrorH\x00\x12h\n\x13\x61uthorization_error\x18\t \x01(\x0e\x32I.google.ads.googleads.v2.errors.AuthorizationErrorEnum.AuthorizationErrorH\x00\x12Y\n\x0einternal_error\x18\n \x01(\x0e\x32?.google.ads.googleads.v2.errors.InternalErrorEnum.InternalErrorH\x00\x12P\n\x0bquota_error\x18\x0b \x01(\x0e\x32\x39.google.ads.googleads.v2.errors.QuotaErrorEnum.QuotaErrorH\x00\x12G\n\x08\x61\x64_error\x18\x0c \x01(\x0e\x32\x33.google.ads.googleads.v2.errors.AdErrorEnum.AdErrorH\x00\x12W\n\x0e\x61\x64_group_error\x18\r \x01(\x0e\x32=.google.ads.googleads.v2.errors.AdGroupErrorEnum.AdGroupErrorH\x00\x12l\n\x15\x63\x61mpaign_budget_error\x18\x0e \x01(\x0e\x32K.google.ads.googleads.v2.errors.CampaignBudgetErrorEnum.CampaignBudgetErrorH\x00\x12Y\n\x0e\x63\x61mpaign_error\x18\x0f \x01(\x0e\x32?.google.ads.googleads.v2.errors.CampaignErrorEnum.CampaignErrorH\x00\x12k\n\x14\x61uthentication_error\x18\x11 \x01(\x0e\x32K.google.ads.googleads.v2.errors.AuthenticationErrorEnum.AuthenticationErrorH\x00\x12s\n\x18\x61\x64_group_criterion_error\x18\x12 \x01(\x0e\x32O.google.ads.googleads.v2.errors.AdGroupCriterionErrorEnum.AdGroupCriterionErrorH\x00\x12\x66\n\x13\x61\x64_customizer_error\x18\x13 \x01(\x0e\x32G.google.ads.googleads.v2.errors.AdCustomizerErrorEnum.AdCustomizerErrorH\x00\x12^\n\x11\x61\x64_group_ad_error\x18\x15 \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.AdGroupAdErrorEnum.AdGroupAdErrorH\x00\x12]\n\x10\x61\x64_sharing_error\x18\x18 \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.AdSharingErrorEnum.AdSharingErrorH\x00\x12J\n\tadx_error\x18\x19 \x01(\x0e\x32\x35.google.ads.googleads.v2.errors.AdxErrorEnum.AdxErrorH\x00\x12P\n\x0b\x61sset_error\x18k \x01(\x0e\x32\x39.google.ads.googleads.v2.errors.AssetErrorEnum.AssetErrorH\x00\x12V\n\rbidding_error\x18\x1a \x01(\x0e\x32=.google.ads.googleads.v2.errors.BiddingErrorEnum.BiddingErrorH\x00\x12u\n\x18\x63\x61mpaign_criterion_error\x18\x1d \x01(\x0e\x32Q.google.ads.googleads.v2.errors.CampaignCriterionErrorEnum.CampaignCriterionErrorH\x00\x12l\n\x15\x63ollection_size_error\x18\x1f \x01(\x0e\x32K.google.ads.googleads.v2.errors.CollectionSizeErrorEnum.CollectionSizeErrorH\x00\x12\x63\n\x12\x63ountry_code_error\x18m \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.CountryCodeErrorEnum.CountryCodeErrorH\x00\x12\\\n\x0f\x63riterion_error\x18  \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.CriterionErrorEnum.CriterionErrorH\x00\x12Y\n\x0e\x63ustomer_error\x18Z \x01(\x0e\x32?.google.ads.googleads.v2.errors.CustomerErrorEnum.CustomerErrorH\x00\x12M\n\ndate_error\x18! \x01(\x0e\x32\x37.google.ads.googleads.v2.errors.DateErrorEnum.DateErrorH\x00\x12]\n\x10\x64\x61te_range_error\x18\" \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.DateRangeErrorEnum.DateRangeErrorH\x00\x12Y\n\x0e\x64istinct_error\x18# \x01(\x0e\x32?.google.ads.googleads.v2.errors.DistinctErrorEnum.DistinctErrorH\x00\x12\x85\x01\n\x1e\x66\x65\x65\x64_attribute_reference_error\x18$ \x01(\x0e\x32[.google.ads.googleads.v2.errors.FeedAttributeReferenceErrorEnum.FeedAttributeReferenceErrorH\x00\x12Y\n\x0e\x66unction_error\x18% \x01(\x0e\x32?.google.ads.googleads.v2.errors.FunctionErrorEnum.FunctionErrorH\x00\x12o\n\x16\x66unction_parsing_error\x18& \x01(\x0e\x32M.google.ads.googleads.v2.errors.FunctionParsingErrorEnum.FunctionParsingErrorH\x00\x12G\n\x08id_error\x18\' \x01(\x0e\x32\x33.google.ads.googleads.v2.errors.IdErrorEnum.IdErrorH\x00\x12P\n\x0bimage_error\x18( \x01(\x0e\x32\x39.google.ads.googleads.v2.errors.ImageErrorEnum.ImageErrorH\x00\x12\x66\n\x13language_code_error\x18n \x01(\x0e\x32G.google.ads.googleads.v2.errors.LanguageCodeErrorEnum.LanguageCodeErrorH\x00\x12\x63\n\x12media_bundle_error\x18* \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.MediaBundleErrorEnum.MediaBundleErrorH\x00\x12\x63\n\x12media_upload_error\x18t \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.MediaUploadErrorEnum.MediaUploadErrorH\x00\x12]\n\x10media_file_error\x18V \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.MediaFileErrorEnum.MediaFileErrorH\x00\x12_\n\x10multiplier_error\x18, \x01(\x0e\x32\x43.google.ads.googleads.v2.errors.MultiplierErrorEnum.MultiplierErrorH\x00\x12|\n\x1bnew_resource_creation_error\x18- \x01(\x0e\x32U.google.ads.googleads.v2.errors.NewResourceCreationErrorEnum.NewResourceCreationErrorH\x00\x12Z\n\x0fnot_empty_error\x18. \x01(\x0e\x32?.google.ads.googleads.v2.errors.NotEmptyErrorEnum.NotEmptyErrorH\x00\x12M\n\nnull_error\x18/ \x01(\x0e\x32\x37.google.ads.googleads.v2.errors.NullErrorEnum.NullErrorH\x00\x12Y\n\x0eoperator_error\x18\x30 \x01(\x0e\x32?.google.ads.googleads.v2.errors.OperatorErrorEnum.OperatorErrorH\x00\x12P\n\x0brange_error\x18\x31 \x01(\x0e\x32\x39.google.ads.googleads.v2.errors.RangeErrorEnum.RangeErrorH\x00\x12k\n\x14recommendation_error\x18: \x01(\x0e\x32K.google.ads.googleads.v2.errors.RecommendationErrorEnum.RecommendationErrorH\x00\x12`\n\x11region_code_error\x18\x33 \x01(\x0e\x32\x43.google.ads.googleads.v2.errors.RegionCodeErrorEnum.RegionCodeErrorH\x00\x12V\n\rsetting_error\x18\x34 \x01(\x0e\x32=.google.ads.googleads.v2.errors.SettingErrorEnum.SettingErrorH\x00\x12\x66\n\x13string_format_error\x18\x35 \x01(\x0e\x32G.google.ads.googleads.v2.errors.StringFormatErrorEnum.StringFormatErrorH\x00\x12\x66\n\x13string_length_error\x18\x36 \x01(\x0e\x32G.google.ads.googleads.v2.errors.StringLengthErrorEnum.StringLengthErrorH\x00\x12\x82\x01\n\x1doperation_access_denied_error\x18\x37 \x01(\x0e\x32Y.google.ads.googleads.v2.errors.OperationAccessDeniedErrorEnum.OperationAccessDeniedErrorH\x00\x12\x7f\n\x1cresource_access_denied_error\x18\x38 \x01(\x0e\x32W.google.ads.googleads.v2.errors.ResourceAccessDeniedErrorEnum.ResourceAccessDeniedErrorH\x00\x12\x92\x01\n#resource_count_limit_exceeded_error\x18\x39 \x01(\x0e\x32\x63.google.ads.googleads.v2.errors.ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededErrorH\x00\x12\x8b\x01\n youtube_video_registration_error\x18u \x01(\x0e\x32_.google.ads.googleads.v2.errors.YoutubeVideoRegistrationErrorEnum.YoutubeVideoRegistrationErrorH\x00\x12z\n\x1b\x61\x64_group_bid_modifier_error\x18; \x01(\x0e\x32S.google.ads.googleads.v2.errors.AdGroupBidModifierErrorEnum.AdGroupBidModifierErrorH\x00\x12V\n\rcontext_error\x18< \x01(\x0e\x32=.google.ads.googleads.v2.errors.ContextErrorEnum.ContextErrorH\x00\x12P\n\x0b\x66ield_error\x18= \x01(\x0e\x32\x39.google.ads.googleads.v2.errors.FieldErrorEnum.FieldErrorH\x00\x12]\n\x10shared_set_error\x18> \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.SharedSetErrorEnum.SharedSetErrorH\x00\x12o\n\x16shared_criterion_error\x18? \x01(\x0e\x32M.google.ads.googleads.v2.errors.SharedCriterionErrorEnum.SharedCriterionErrorH\x00\x12v\n\x19\x63\x61mpaign_shared_set_error\x18@ \x01(\x0e\x32Q.google.ads.googleads.v2.errors.CampaignSharedSetErrorEnum.CampaignSharedSetErrorH\x00\x12r\n\x17\x63onversion_action_error\x18\x41 \x01(\x0e\x32O.google.ads.googleads.v2.errors.ConversionActionErrorEnum.ConversionActionErrorH\x00\x12\x91\x01\n\"conversion_adjustment_upload_error\x18s \x01(\x0e\x32\x63.google.ads.googleads.v2.errors.ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadErrorH\x00\x12r\n\x17\x63onversion_upload_error\x18o \x01(\x0e\x32O.google.ads.googleads.v2.errors.ConversionUploadErrorEnum.ConversionUploadErrorH\x00\x12S\n\x0cheader_error\x18\x42 \x01(\x0e\x32;.google.ads.googleads.v2.errors.HeaderErrorEnum.HeaderErrorH\x00\x12Y\n\x0e\x64\x61tabase_error\x18\x43 \x01(\x0e\x32?.google.ads.googleads.v2.errors.DatabaseErrorEnum.DatabaseErrorH\x00\x12i\n\x14policy_finding_error\x18\x44 \x01(\x0e\x32I.google.ads.googleads.v2.errors.PolicyFindingErrorEnum.PolicyFindingErrorH\x00\x12M\n\nenum_error\x18\x46 \x01(\x0e\x32\x37.google.ads.googleads.v2.errors.EnumErrorEnum.EnumErrorH\x00\x12\x63\n\x12keyword_plan_error\x18G \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.KeywordPlanErrorEnum.KeywordPlanErrorH\x00\x12|\n\x1bkeyword_plan_campaign_error\x18H \x01(\x0e\x32U.google.ads.googleads.v2.errors.KeywordPlanCampaignErrorEnum.KeywordPlanCampaignErrorH\x00\x12\x92\x01\n#keyword_plan_negative_keyword_error\x18I \x01(\x0e\x32\x63.google.ads.googleads.v2.errors.KeywordPlanNegativeKeywordErrorEnum.KeywordPlanNegativeKeywordErrorH\x00\x12z\n\x1bkeyword_plan_ad_group_error\x18J \x01(\x0e\x32S.google.ads.googleads.v2.errors.KeywordPlanAdGroupErrorEnum.KeywordPlanAdGroupErrorH\x00\x12y\n\x1akeyword_plan_keyword_error\x18K \x01(\x0e\x32S.google.ads.googleads.v2.errors.KeywordPlanKeywordErrorEnum.KeywordPlanKeywordErrorH\x00\x12p\n\x17keyword_plan_idea_error\x18L \x01(\x0e\x32M.google.ads.googleads.v2.errors.KeywordPlanIdeaErrorEnum.KeywordPlanIdeaErrorH\x00\x12\x82\x01\n\x1d\x61\x63\x63ount_budget_proposal_error\x18M \x01(\x0e\x32Y.google.ads.googleads.v2.errors.AccountBudgetProposalErrorEnum.AccountBudgetProposalErrorH\x00\x12Z\n\x0fuser_list_error\x18N \x01(\x0e\x32?.google.ads.googleads.v2.errors.UserListErrorEnum.UserListErrorH\x00\x12\x66\n\x13\x63hange_status_error\x18O \x01(\x0e\x32G.google.ads.googleads.v2.errors.ChangeStatusErrorEnum.ChangeStatusErrorH\x00\x12M\n\nfeed_error\x18P \x01(\x0e\x32\x37.google.ads.googleads.v2.errors.FeedErrorEnum.FeedErrorH\x00\x12\x95\x01\n$geo_target_constant_suggestion_error\x18Q \x01(\x0e\x32\x65.google.ads.googleads.v2.errors.GeoTargetConstantSuggestionErrorEnum.GeoTargetConstantSuggestionErrorH\x00\x12i\n\x14\x63\x61mpaign_draft_error\x18R \x01(\x0e\x32I.google.ads.googleads.v2.errors.CampaignDraftErrorEnum.CampaignDraftErrorH\x00\x12Z\n\x0f\x66\x65\x65\x64_item_error\x18S \x01(\x0e\x32?.google.ads.googleads.v2.errors.FeedItemErrorEnum.FeedItemErrorH\x00\x12P\n\x0blabel_error\x18T \x01(\x0e\x32\x39.google.ads.googleads.v2.errors.LabelErrorEnum.LabelErrorH\x00\x12\x66\n\x13\x62illing_setup_error\x18W \x01(\x0e\x32G.google.ads.googleads.v2.errors.BillingSetupErrorEnum.BillingSetupErrorH\x00\x12y\n\x1a\x63ustomer_client_link_error\x18X \x01(\x0e\x32S.google.ads.googleads.v2.errors.CustomerClientLinkErrorEnum.CustomerClientLinkErrorH\x00\x12|\n\x1b\x63ustomer_manager_link_error\x18[ \x01(\x0e\x32U.google.ads.googleads.v2.errors.CustomerManagerLinkErrorEnum.CustomerManagerLinkErrorH\x00\x12\x63\n\x12\x66\x65\x65\x64_mapping_error\x18\\ \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.FeedMappingErrorEnum.FeedMappingErrorH\x00\x12\x66\n\x13\x63ustomer_feed_error\x18] \x01(\x0e\x32G.google.ads.googleads.v2.errors.CustomerFeedErrorEnum.CustomerFeedErrorH\x00\x12\x64\n\x13\x61\x64_group_feed_error\x18^ \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.AdGroupFeedErrorEnum.AdGroupFeedErrorH\x00\x12\x66\n\x13\x63\x61mpaign_feed_error\x18` \x01(\x0e\x32G.google.ads.googleads.v2.errors.CampaignFeedErrorEnum.CampaignFeedErrorH\x00\x12l\n\x15\x63ustom_interest_error\x18\x61 \x01(\x0e\x32K.google.ads.googleads.v2.errors.CustomInterestErrorEnum.CustomInterestErrorH\x00\x12x\n\x19\x63\x61mpaign_experiment_error\x18\x62 \x01(\x0e\x32S.google.ads.googleads.v2.errors.CampaignExperimentErrorEnum.CampaignExperimentErrorH\x00\x12v\n\x19\x65xtension_feed_item_error\x18\x64 \x01(\x0e\x32Q.google.ads.googleads.v2.errors.ExtensionFeedItemErrorEnum.ExtensionFeedItemErrorH\x00\x12\x63\n\x12\x61\x64_parameter_error\x18\x65 \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.AdParameterErrorEnum.AdParameterErrorH\x00\x12y\n\x1a\x66\x65\x65\x64_item_validation_error\x18\x66 \x01(\x0e\x32S.google.ads.googleads.v2.errors.FeedItemValidationErrorEnum.FeedItemValidationErrorH\x00\x12r\n\x17\x65xtension_setting_error\x18g \x01(\x0e\x32O.google.ads.googleads.v2.errors.ExtensionSettingErrorEnum.ExtensionSettingErrorH\x00\x12m\n\x16\x66\x65\x65\x64_item_target_error\x18h \x01(\x0e\x32K.google.ads.googleads.v2.errors.FeedItemTargetErrorEnum.FeedItemTargetErrorH\x00\x12o\n\x16policy_violation_error\x18i \x01(\x0e\x32M.google.ads.googleads.v2.errors.PolicyViolationErrorEnum.PolicyViolationErrorH\x00\x12]\n\x10mutate_job_error\x18l \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.MutateJobErrorEnum.MutateJobErrorH\x00\x12l\n\x15partial_failure_error\x18p \x01(\x0e\x32K.google.ads.googleads.v2.errors.PartialFailureErrorEnum.PartialFailureErrorH\x00\x12\x8e\x01\n!policy_validation_parameter_error\x18r \x01(\x0e\x32\x61.google.ads.googleads.v2.errors.PolicyValidationParameterErrorEnum.PolicyValidationParameterErrorH\x00\x12]\n\x10size_limit_error\x18v \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.SizeLimitErrorEnum.SizeLimitErrorH\x00\x12l\n\x15not_whitelisted_error\x18x \x01(\x0e\x32K.google.ads.googleads.v2.errors.NotWhitelistedErrorEnum.NotWhitelistedErrorH\x00\x12\x63\n\x12manager_link_error\x18y \x01(\x0e\x32\x45.google.ads.googleads.v2.errors.ManagerLinkErrorEnum.ManagerLinkErrorH\x00\x12\x66\n\x13\x63urrency_code_error\x18z \x01(\x0e\x32G.google.ads.googleads.v2.errors.CurrencyCodeErrorEnum.CurrencyCodeErrorH\x00\x12r\n\x17\x61\x63\x63\x65ss_invitation_error\x18| \x01(\x0e\x32O.google.ads.googleads.v2.errors.AccessInvitationErrorEnum.AccessInvitationErrorH\x00\x12]\n\x10reach_plan_error\x18} \x01(\x0e\x32\x41.google.ads.googleads.v2.errors.ReachPlanErrorEnum.ReachPlanErrorH\x00\x12V\n\rinvoice_error\x18~ \x01(\x0e\x32=.google.ads.googleads.v2.errors.InvoiceErrorEnum.InvoiceErrorH\x00\x42\x0c\n\nerror_code\"\xc0\x01\n\rErrorLocation\x12[\n\x13\x66ield_path_elements\x18\x02 \x03(\x0b\x32>.google.ads.googleads.v2.errors.ErrorLocation.FieldPathElement\x1aR\n\x10\x46ieldPathElement\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12*\n\x05index\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xde\x01\n\x0c\x45rrorDetails\x12\x1e\n\x16unpublished_error_code\x18\x01 \x01(\t\x12X\n\x18policy_violation_details\x18\x02 \x01(\x0b\x32\x36.google.ads.googleads.v2.errors.PolicyViolationDetails\x12T\n\x16policy_finding_details\x18\x03 \x01(\x0b\x32\x34.google.ads.googleads.v2.errors.PolicyFindingDetails\"\xb3\x01\n\x16PolicyViolationDetails\x12#\n\x1b\x65xternal_policy_description\x18\x02 \x01(\t\x12?\n\x03key\x18\x04 \x01(\x0b\x32\x32.google.ads.googleads.v2.common.PolicyViolationKey\x12\x1c\n\x14\x65xternal_policy_name\x18\x05 \x01(\t\x12\x15\n\ris_exemptible\x18\x06 \x01(\x08\"f\n\x14PolicyFindingDetails\x12N\n\x14policy_topic_entries\x18\x01 \x03(\x0b\x32\x30.google.ads.googleads.v2.common.PolicyTopicEntryB\xe6\x01\n\"com.google.ads.googleads.v2.errorsB\x0b\x45rrorsProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_value__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_access__invitation__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_account__budget__proposal__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__customizer__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__ad__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__bid__modifier__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__criterion__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__feed__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__parameter__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__sharing__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_adx__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_asset__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_authentication__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_authorization__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_bidding__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_bidding__strategy__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_billing__setup__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__budget__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__criterion__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__draft__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__experiment__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__feed__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__shared__set__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_change__status__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_collection__size__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_context__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__action__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__adjustment__upload__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__upload__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_country__code__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_criterion__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_currency__code__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_custom__interest__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__client__link__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__feed__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__manager__link__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_database__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_date__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_date__range__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_distinct__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_enum__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_extension__feed__item__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_extension__setting__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__attribute__reference__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__target__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__mapping__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_field__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_field__mask__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_function__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_function__parsing__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_geo__target__constant__suggestion__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_header__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_id__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_image__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_internal__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_invoice__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__ad__group__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__campaign__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__idea__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__keyword__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__negative__keyword__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_label__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_language__code__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_list__operation__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_manager__link__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__bundle__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__file__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__upload__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_multiplier__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_mutate__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_mutate__job__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_new__resource__creation__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_not__empty__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_not__whitelisted__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_null__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_operation__access__denied__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_operator__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_partial__failure__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__finding__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__validation__parameter__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__violation__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_query__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_quota__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_range__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_reach__plan__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_recommendation__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_region__code__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_request__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_resource__access__denied__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_resource__count__limit__exceeded__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_setting__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_shared__criterion__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_shared__set__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_size__limit__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_string__format__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_string__length__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_url__field__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_user__list__error__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_youtube__video__registration__error__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_GOOGLEADSFAILURE = _descriptor.Descriptor(
  name='GoogleAdsFailure',
  full_name='google.ads.googleads.v2.errors.GoogleAdsFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='errors', full_name='google.ads.googleads.v2.errors.GoogleAdsFailure.errors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7036,
  serialized_end=7118,
)


_GOOGLEADSERROR = _descriptor.Descriptor(
  name='GoogleAdsError',
  full_name='google.ads.googleads.v2.errors.GoogleAdsError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_code', full_name='google.ads.googleads.v2.errors.GoogleAdsError.error_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='google.ads.googleads.v2.errors.GoogleAdsError.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trigger', full_name='google.ads.googleads.v2.errors.GoogleAdsError.trigger', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='google.ads.googleads.v2.errors.GoogleAdsError.location', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='google.ads.googleads.v2.errors.GoogleAdsError.details', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7121,
  serialized_end=7401,
)


_ERRORCODE = _descriptor.Descriptor(
  name='ErrorCode',
  full_name='google.ads.googleads.v2.errors.ErrorCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_error', full_name='google.ads.googleads.v2.errors.ErrorCode.request_error', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bidding_strategy_error', full_name='google.ads.googleads.v2.errors.ErrorCode.bidding_strategy_error', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_field_error', full_name='google.ads.googleads.v2.errors.ErrorCode.url_field_error', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list_operation_error', full_name='google.ads.googleads.v2.errors.ErrorCode.list_operation_error', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_error', full_name='google.ads.googleads.v2.errors.ErrorCode.query_error', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mutate_error', full_name='google.ads.googleads.v2.errors.ErrorCode.mutate_error', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_mask_error', full_name='google.ads.googleads.v2.errors.ErrorCode.field_mask_error', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorization_error', full_name='google.ads.googleads.v2.errors.ErrorCode.authorization_error', index=7,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='internal_error', full_name='google.ads.googleads.v2.errors.ErrorCode.internal_error', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quota_error', full_name='google.ads.googleads.v2.errors.ErrorCode.quota_error', index=9,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_error', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_group_error', index=11,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_budget_error', full_name='google.ads.googleads.v2.errors.ErrorCode.campaign_budget_error', index=12,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_error', full_name='google.ads.googleads.v2.errors.ErrorCode.campaign_error', index=13,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authentication_error', full_name='google.ads.googleads.v2.errors.ErrorCode.authentication_error', index=14,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_criterion_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_group_criterion_error', index=15,
      number=18, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_customizer_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_customizer_error', index=16,
      number=19, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_ad_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_group_ad_error', index=17,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_sharing_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_sharing_error', index=18,
      number=24, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adx_error', full_name='google.ads.googleads.v2.errors.ErrorCode.adx_error', index=19,
      number=25, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_error', full_name='google.ads.googleads.v2.errors.ErrorCode.asset_error', index=20,
      number=107, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bidding_error', full_name='google.ads.googleads.v2.errors.ErrorCode.bidding_error', index=21,
      number=26, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_criterion_error', full_name='google.ads.googleads.v2.errors.ErrorCode.campaign_criterion_error', index=22,
      number=29, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='collection_size_error', full_name='google.ads.googleads.v2.errors.ErrorCode.collection_size_error', index=23,
      number=31, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_code_error', full_name='google.ads.googleads.v2.errors.ErrorCode.country_code_error', index=24,
      number=109, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_error', full_name='google.ads.googleads.v2.errors.ErrorCode.criterion_error', index=25,
      number=32, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_error', full_name='google.ads.googleads.v2.errors.ErrorCode.customer_error', index=26,
      number=90, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_error', full_name='google.ads.googleads.v2.errors.ErrorCode.date_error', index=27,
      number=33, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='date_range_error', full_name='google.ads.googleads.v2.errors.ErrorCode.date_range_error', index=28,
      number=34, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distinct_error', full_name='google.ads.googleads.v2.errors.ErrorCode.distinct_error', index=29,
      number=35, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_attribute_reference_error', full_name='google.ads.googleads.v2.errors.ErrorCode.feed_attribute_reference_error', index=30,
      number=36, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_error', full_name='google.ads.googleads.v2.errors.ErrorCode.function_error', index=31,
      number=37, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='function_parsing_error', full_name='google.ads.googleads.v2.errors.ErrorCode.function_parsing_error', index=32,
      number=38, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id_error', full_name='google.ads.googleads.v2.errors.ErrorCode.id_error', index=33,
      number=39, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_error', full_name='google.ads.googleads.v2.errors.ErrorCode.image_error', index=34,
      number=40, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code_error', full_name='google.ads.googleads.v2.errors.ErrorCode.language_code_error', index=35,
      number=110, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_bundle_error', full_name='google.ads.googleads.v2.errors.ErrorCode.media_bundle_error', index=36,
      number=42, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_upload_error', full_name='google.ads.googleads.v2.errors.ErrorCode.media_upload_error', index=37,
      number=116, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='media_file_error', full_name='google.ads.googleads.v2.errors.ErrorCode.media_file_error', index=38,
      number=86, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='multiplier_error', full_name='google.ads.googleads.v2.errors.ErrorCode.multiplier_error', index=39,
      number=44, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_resource_creation_error', full_name='google.ads.googleads.v2.errors.ErrorCode.new_resource_creation_error', index=40,
      number=45, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='not_empty_error', full_name='google.ads.googleads.v2.errors.ErrorCode.not_empty_error', index=41,
      number=46, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='null_error', full_name='google.ads.googleads.v2.errors.ErrorCode.null_error', index=42,
      number=47, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator_error', full_name='google.ads.googleads.v2.errors.ErrorCode.operator_error', index=43,
      number=48, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='range_error', full_name='google.ads.googleads.v2.errors.ErrorCode.range_error', index=44,
      number=49, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='recommendation_error', full_name='google.ads.googleads.v2.errors.ErrorCode.recommendation_error', index=45,
      number=58, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='region_code_error', full_name='google.ads.googleads.v2.errors.ErrorCode.region_code_error', index=46,
      number=51, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='setting_error', full_name='google.ads.googleads.v2.errors.ErrorCode.setting_error', index=47,
      number=52, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_format_error', full_name='google.ads.googleads.v2.errors.ErrorCode.string_format_error', index=48,
      number=53, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_length_error', full_name='google.ads.googleads.v2.errors.ErrorCode.string_length_error', index=49,
      number=54, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation_access_denied_error', full_name='google.ads.googleads.v2.errors.ErrorCode.operation_access_denied_error', index=50,
      number=55, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_access_denied_error', full_name='google.ads.googleads.v2.errors.ErrorCode.resource_access_denied_error', index=51,
      number=56, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_count_limit_exceeded_error', full_name='google.ads.googleads.v2.errors.ErrorCode.resource_count_limit_exceeded_error', index=52,
      number=57, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_video_registration_error', full_name='google.ads.googleads.v2.errors.ErrorCode.youtube_video_registration_error', index=53,
      number=117, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_bid_modifier_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_group_bid_modifier_error', index=54,
      number=59, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context_error', full_name='google.ads.googleads.v2.errors.ErrorCode.context_error', index=55,
      number=60, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field_error', full_name='google.ads.googleads.v2.errors.ErrorCode.field_error', index=56,
      number=61, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_set_error', full_name='google.ads.googleads.v2.errors.ErrorCode.shared_set_error', index=57,
      number=62, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_criterion_error', full_name='google.ads.googleads.v2.errors.ErrorCode.shared_criterion_error', index=58,
      number=63, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_shared_set_error', full_name='google.ads.googleads.v2.errors.ErrorCode.campaign_shared_set_error', index=59,
      number=64, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_action_error', full_name='google.ads.googleads.v2.errors.ErrorCode.conversion_action_error', index=60,
      number=65, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_adjustment_upload_error', full_name='google.ads.googleads.v2.errors.ErrorCode.conversion_adjustment_upload_error', index=61,
      number=115, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_upload_error', full_name='google.ads.googleads.v2.errors.ErrorCode.conversion_upload_error', index=62,
      number=111, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_error', full_name='google.ads.googleads.v2.errors.ErrorCode.header_error', index=63,
      number=66, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='database_error', full_name='google.ads.googleads.v2.errors.ErrorCode.database_error', index=64,
      number=67, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_finding_error', full_name='google.ads.googleads.v2.errors.ErrorCode.policy_finding_error', index=65,
      number=68, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enum_error', full_name='google.ads.googleads.v2.errors.ErrorCode.enum_error', index=66,
      number=70, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_error', full_name='google.ads.googleads.v2.errors.ErrorCode.keyword_plan_error', index=67,
      number=71, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_campaign_error', full_name='google.ads.googleads.v2.errors.ErrorCode.keyword_plan_campaign_error', index=68,
      number=72, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_negative_keyword_error', full_name='google.ads.googleads.v2.errors.ErrorCode.keyword_plan_negative_keyword_error', index=69,
      number=73, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_ad_group_error', full_name='google.ads.googleads.v2.errors.ErrorCode.keyword_plan_ad_group_error', index=70,
      number=74, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_keyword_error', full_name='google.ads.googleads.v2.errors.ErrorCode.keyword_plan_keyword_error', index=71,
      number=75, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_idea_error', full_name='google.ads.googleads.v2.errors.ErrorCode.keyword_plan_idea_error', index=72,
      number=76, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_budget_proposal_error', full_name='google.ads.googleads.v2.errors.ErrorCode.account_budget_proposal_error', index=73,
      number=77, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_list_error', full_name='google.ads.googleads.v2.errors.ErrorCode.user_list_error', index=74,
      number=78, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='change_status_error', full_name='google.ads.googleads.v2.errors.ErrorCode.change_status_error', index=75,
      number=79, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_error', full_name='google.ads.googleads.v2.errors.ErrorCode.feed_error', index=76,
      number=80, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_constant_suggestion_error', full_name='google.ads.googleads.v2.errors.ErrorCode.geo_target_constant_suggestion_error', index=77,
      number=81, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_draft_error', full_name='google.ads.googleads.v2.errors.ErrorCode.campaign_draft_error', index=78,
      number=82, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_error', full_name='google.ads.googleads.v2.errors.ErrorCode.feed_item_error', index=79,
      number=83, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label_error', full_name='google.ads.googleads.v2.errors.ErrorCode.label_error', index=80,
      number=84, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_setup_error', full_name='google.ads.googleads.v2.errors.ErrorCode.billing_setup_error', index=81,
      number=87, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_client_link_error', full_name='google.ads.googleads.v2.errors.ErrorCode.customer_client_link_error', index=82,
      number=88, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_manager_link_error', full_name='google.ads.googleads.v2.errors.ErrorCode.customer_manager_link_error', index=83,
      number=91, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_mapping_error', full_name='google.ads.googleads.v2.errors.ErrorCode.feed_mapping_error', index=84,
      number=92, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='customer_feed_error', full_name='google.ads.googleads.v2.errors.ErrorCode.customer_feed_error', index=85,
      number=93, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group_feed_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_group_feed_error', index=86,
      number=94, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_feed_error', full_name='google.ads.googleads.v2.errors.ErrorCode.campaign_feed_error', index=87,
      number=96, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='custom_interest_error', full_name='google.ads.googleads.v2.errors.ErrorCode.custom_interest_error', index=88,
      number=97, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign_experiment_error', full_name='google.ads.googleads.v2.errors.ErrorCode.campaign_experiment_error', index=89,
      number=98, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_feed_item_error', full_name='google.ads.googleads.v2.errors.ErrorCode.extension_feed_item_error', index=90,
      number=100, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_parameter_error', full_name='google.ads.googleads.v2.errors.ErrorCode.ad_parameter_error', index=91,
      number=101, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_validation_error', full_name='google.ads.googleads.v2.errors.ErrorCode.feed_item_validation_error', index=92,
      number=102, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extension_setting_error', full_name='google.ads.googleads.v2.errors.ErrorCode.extension_setting_error', index=93,
      number=103, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_target_error', full_name='google.ads.googleads.v2.errors.ErrorCode.feed_item_target_error', index=94,
      number=104, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_violation_error', full_name='google.ads.googleads.v2.errors.ErrorCode.policy_violation_error', index=95,
      number=105, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mutate_job_error', full_name='google.ads.googleads.v2.errors.ErrorCode.mutate_job_error', index=96,
      number=108, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v2.errors.ErrorCode.partial_failure_error', index=97,
      number=112, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_validation_parameter_error', full_name='google.ads.googleads.v2.errors.ErrorCode.policy_validation_parameter_error', index=98,
      number=114, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size_limit_error', full_name='google.ads.googleads.v2.errors.ErrorCode.size_limit_error', index=99,
      number=118, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='not_whitelisted_error', full_name='google.ads.googleads.v2.errors.ErrorCode.not_whitelisted_error', index=100,
      number=120, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manager_link_error', full_name='google.ads.googleads.v2.errors.ErrorCode.manager_link_error', index=101,
      number=121, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code_error', full_name='google.ads.googleads.v2.errors.ErrorCode.currency_code_error', index=102,
      number=122, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='access_invitation_error', full_name='google.ads.googleads.v2.errors.ErrorCode.access_invitation_error', index=103,
      number=124, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reach_plan_error', full_name='google.ads.googleads.v2.errors.ErrorCode.reach_plan_error', index=104,
      number=125, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invoice_error', full_name='google.ads.googleads.v2.errors.ErrorCode.invoice_error', index=105,
      number=126, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='error_code', full_name='google.ads.googleads.v2.errors.ErrorCode.error_code',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=7404,
  serialized_end=18480,
)


_ERRORLOCATION_FIELDPATHELEMENT = _descriptor.Descriptor(
  name='FieldPathElement',
  full_name='google.ads.googleads.v2.errors.ErrorLocation.FieldPathElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_name', full_name='google.ads.googleads.v2.errors.ErrorLocation.FieldPathElement.field_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='google.ads.googleads.v2.errors.ErrorLocation.FieldPathElement.index', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18593,
  serialized_end=18675,
)

_ERRORLOCATION = _descriptor.Descriptor(
  name='ErrorLocation',
  full_name='google.ads.googleads.v2.errors.ErrorLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_path_elements', full_name='google.ads.googleads.v2.errors.ErrorLocation.field_path_elements', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ERRORLOCATION_FIELDPATHELEMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18483,
  serialized_end=18675,
)


_ERRORDETAILS = _descriptor.Descriptor(
  name='ErrorDetails',
  full_name='google.ads.googleads.v2.errors.ErrorDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='unpublished_error_code', full_name='google.ads.googleads.v2.errors.ErrorDetails.unpublished_error_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_violation_details', full_name='google.ads.googleads.v2.errors.ErrorDetails.policy_violation_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_finding_details', full_name='google.ads.googleads.v2.errors.ErrorDetails.policy_finding_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18678,
  serialized_end=18900,
)


_POLICYVIOLATIONDETAILS = _descriptor.Descriptor(
  name='PolicyViolationDetails',
  full_name='google.ads.googleads.v2.errors.PolicyViolationDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='external_policy_description', full_name='google.ads.googleads.v2.errors.PolicyViolationDetails.external_policy_description', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='key', full_name='google.ads.googleads.v2.errors.PolicyViolationDetails.key', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='external_policy_name', full_name='google.ads.googleads.v2.errors.PolicyViolationDetails.external_policy_name', index=2,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_exemptible', full_name='google.ads.googleads.v2.errors.PolicyViolationDetails.is_exemptible', index=3,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18903,
  serialized_end=19082,
)


_POLICYFINDINGDETAILS = _descriptor.Descriptor(
  name='PolicyFindingDetails',
  full_name='google.ads.googleads.v2.errors.PolicyFindingDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_topic_entries', full_name='google.ads.googleads.v2.errors.PolicyFindingDetails.policy_topic_entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19084,
  serialized_end=19186,
)

_GOOGLEADSFAILURE.fields_by_name['errors'].message_type = _GOOGLEADSERROR
_GOOGLEADSERROR.fields_by_name['error_code'].message_type = _ERRORCODE
_GOOGLEADSERROR.fields_by_name['trigger'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_value__pb2._VALUE
_GOOGLEADSERROR.fields_by_name['location'].message_type = _ERRORLOCATION
_GOOGLEADSERROR.fields_by_name['details'].message_type = _ERRORDETAILS
_ERRORCODE.fields_by_name['request_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_request__error__pb2._REQUESTERRORENUM_REQUESTERROR
_ERRORCODE.fields_by_name['bidding_strategy_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_bidding__strategy__error__pb2._BIDDINGSTRATEGYERRORENUM_BIDDINGSTRATEGYERROR
_ERRORCODE.fields_by_name['url_field_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_url__field__error__pb2._URLFIELDERRORENUM_URLFIELDERROR
_ERRORCODE.fields_by_name['list_operation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_list__operation__error__pb2._LISTOPERATIONERRORENUM_LISTOPERATIONERROR
_ERRORCODE.fields_by_name['query_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_query__error__pb2._QUERYERRORENUM_QUERYERROR
_ERRORCODE.fields_by_name['mutate_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_mutate__error__pb2._MUTATEERRORENUM_MUTATEERROR
_ERRORCODE.fields_by_name['field_mask_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_field__mask__error__pb2._FIELDMASKERRORENUM_FIELDMASKERROR
_ERRORCODE.fields_by_name['authorization_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_authorization__error__pb2._AUTHORIZATIONERRORENUM_AUTHORIZATIONERROR
_ERRORCODE.fields_by_name['internal_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_internal__error__pb2._INTERNALERRORENUM_INTERNALERROR
_ERRORCODE.fields_by_name['quota_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_quota__error__pb2._QUOTAERRORENUM_QUOTAERROR
_ERRORCODE.fields_by_name['ad_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__error__pb2._ADERRORENUM_ADERROR
_ERRORCODE.fields_by_name['ad_group_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__error__pb2._ADGROUPERRORENUM_ADGROUPERROR
_ERRORCODE.fields_by_name['campaign_budget_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__budget__error__pb2._CAMPAIGNBUDGETERRORENUM_CAMPAIGNBUDGETERROR
_ERRORCODE.fields_by_name['campaign_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__error__pb2._CAMPAIGNERRORENUM_CAMPAIGNERROR
_ERRORCODE.fields_by_name['authentication_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_authentication__error__pb2._AUTHENTICATIONERRORENUM_AUTHENTICATIONERROR
_ERRORCODE.fields_by_name['ad_group_criterion_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__criterion__error__pb2._ADGROUPCRITERIONERRORENUM_ADGROUPCRITERIONERROR
_ERRORCODE.fields_by_name['ad_customizer_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__customizer__error__pb2._ADCUSTOMIZERERRORENUM_ADCUSTOMIZERERROR
_ERRORCODE.fields_by_name['ad_group_ad_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__ad__error__pb2._ADGROUPADERRORENUM_ADGROUPADERROR
_ERRORCODE.fields_by_name['ad_sharing_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__sharing__error__pb2._ADSHARINGERRORENUM_ADSHARINGERROR
_ERRORCODE.fields_by_name['adx_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_adx__error__pb2._ADXERRORENUM_ADXERROR
_ERRORCODE.fields_by_name['asset_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_asset__error__pb2._ASSETERRORENUM_ASSETERROR
_ERRORCODE.fields_by_name['bidding_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_bidding__error__pb2._BIDDINGERRORENUM_BIDDINGERROR
_ERRORCODE.fields_by_name['campaign_criterion_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__criterion__error__pb2._CAMPAIGNCRITERIONERRORENUM_CAMPAIGNCRITERIONERROR
_ERRORCODE.fields_by_name['collection_size_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_collection__size__error__pb2._COLLECTIONSIZEERRORENUM_COLLECTIONSIZEERROR
_ERRORCODE.fields_by_name['country_code_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_country__code__error__pb2._COUNTRYCODEERRORENUM_COUNTRYCODEERROR
_ERRORCODE.fields_by_name['criterion_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_criterion__error__pb2._CRITERIONERRORENUM_CRITERIONERROR
_ERRORCODE.fields_by_name['customer_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__error__pb2._CUSTOMERERRORENUM_CUSTOMERERROR
_ERRORCODE.fields_by_name['date_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_date__error__pb2._DATEERRORENUM_DATEERROR
_ERRORCODE.fields_by_name['date_range_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_date__range__error__pb2._DATERANGEERRORENUM_DATERANGEERROR
_ERRORCODE.fields_by_name['distinct_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_distinct__error__pb2._DISTINCTERRORENUM_DISTINCTERROR
_ERRORCODE.fields_by_name['feed_attribute_reference_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__attribute__reference__error__pb2._FEEDATTRIBUTEREFERENCEERRORENUM_FEEDATTRIBUTEREFERENCEERROR
_ERRORCODE.fields_by_name['function_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_function__error__pb2._FUNCTIONERRORENUM_FUNCTIONERROR
_ERRORCODE.fields_by_name['function_parsing_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_function__parsing__error__pb2._FUNCTIONPARSINGERRORENUM_FUNCTIONPARSINGERROR
_ERRORCODE.fields_by_name['id_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_id__error__pb2._IDERRORENUM_IDERROR
_ERRORCODE.fields_by_name['image_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_image__error__pb2._IMAGEERRORENUM_IMAGEERROR
_ERRORCODE.fields_by_name['language_code_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_language__code__error__pb2._LANGUAGECODEERRORENUM_LANGUAGECODEERROR
_ERRORCODE.fields_by_name['media_bundle_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__bundle__error__pb2._MEDIABUNDLEERRORENUM_MEDIABUNDLEERROR
_ERRORCODE.fields_by_name['media_upload_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__upload__error__pb2._MEDIAUPLOADERRORENUM_MEDIAUPLOADERROR
_ERRORCODE.fields_by_name['media_file_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_media__file__error__pb2._MEDIAFILEERRORENUM_MEDIAFILEERROR
_ERRORCODE.fields_by_name['multiplier_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_multiplier__error__pb2._MULTIPLIERERRORENUM_MULTIPLIERERROR
_ERRORCODE.fields_by_name['new_resource_creation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_new__resource__creation__error__pb2._NEWRESOURCECREATIONERRORENUM_NEWRESOURCECREATIONERROR
_ERRORCODE.fields_by_name['not_empty_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_not__empty__error__pb2._NOTEMPTYERRORENUM_NOTEMPTYERROR
_ERRORCODE.fields_by_name['null_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_null__error__pb2._NULLERRORENUM_NULLERROR
_ERRORCODE.fields_by_name['operator_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_operator__error__pb2._OPERATORERRORENUM_OPERATORERROR
_ERRORCODE.fields_by_name['range_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_range__error__pb2._RANGEERRORENUM_RANGEERROR
_ERRORCODE.fields_by_name['recommendation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_recommendation__error__pb2._RECOMMENDATIONERRORENUM_RECOMMENDATIONERROR
_ERRORCODE.fields_by_name['region_code_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_region__code__error__pb2._REGIONCODEERRORENUM_REGIONCODEERROR
_ERRORCODE.fields_by_name['setting_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_setting__error__pb2._SETTINGERRORENUM_SETTINGERROR
_ERRORCODE.fields_by_name['string_format_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_string__format__error__pb2._STRINGFORMATERRORENUM_STRINGFORMATERROR
_ERRORCODE.fields_by_name['string_length_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_string__length__error__pb2._STRINGLENGTHERRORENUM_STRINGLENGTHERROR
_ERRORCODE.fields_by_name['operation_access_denied_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_operation__access__denied__error__pb2._OPERATIONACCESSDENIEDERRORENUM_OPERATIONACCESSDENIEDERROR
_ERRORCODE.fields_by_name['resource_access_denied_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_resource__access__denied__error__pb2._RESOURCEACCESSDENIEDERRORENUM_RESOURCEACCESSDENIEDERROR
_ERRORCODE.fields_by_name['resource_count_limit_exceeded_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_resource__count__limit__exceeded__error__pb2._RESOURCECOUNTLIMITEXCEEDEDERRORENUM_RESOURCECOUNTLIMITEXCEEDEDERROR
_ERRORCODE.fields_by_name['youtube_video_registration_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_youtube__video__registration__error__pb2._YOUTUBEVIDEOREGISTRATIONERRORENUM_YOUTUBEVIDEOREGISTRATIONERROR
_ERRORCODE.fields_by_name['ad_group_bid_modifier_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__bid__modifier__error__pb2._ADGROUPBIDMODIFIERERRORENUM_ADGROUPBIDMODIFIERERROR
_ERRORCODE.fields_by_name['context_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_context__error__pb2._CONTEXTERRORENUM_CONTEXTERROR
_ERRORCODE.fields_by_name['field_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_field__error__pb2._FIELDERRORENUM_FIELDERROR
_ERRORCODE.fields_by_name['shared_set_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_shared__set__error__pb2._SHAREDSETERRORENUM_SHAREDSETERROR
_ERRORCODE.fields_by_name['shared_criterion_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_shared__criterion__error__pb2._SHAREDCRITERIONERRORENUM_SHAREDCRITERIONERROR
_ERRORCODE.fields_by_name['campaign_shared_set_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__shared__set__error__pb2._CAMPAIGNSHAREDSETERRORENUM_CAMPAIGNSHAREDSETERROR
_ERRORCODE.fields_by_name['conversion_action_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__action__error__pb2._CONVERSIONACTIONERRORENUM_CONVERSIONACTIONERROR
_ERRORCODE.fields_by_name['conversion_adjustment_upload_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__adjustment__upload__error__pb2._CONVERSIONADJUSTMENTUPLOADERRORENUM_CONVERSIONADJUSTMENTUPLOADERROR
_ERRORCODE.fields_by_name['conversion_upload_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_conversion__upload__error__pb2._CONVERSIONUPLOADERRORENUM_CONVERSIONUPLOADERROR
_ERRORCODE.fields_by_name['header_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_header__error__pb2._HEADERERRORENUM_HEADERERROR
_ERRORCODE.fields_by_name['database_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_database__error__pb2._DATABASEERRORENUM_DATABASEERROR
_ERRORCODE.fields_by_name['policy_finding_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__finding__error__pb2._POLICYFINDINGERRORENUM_POLICYFINDINGERROR
_ERRORCODE.fields_by_name['enum_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_enum__error__pb2._ENUMERRORENUM_ENUMERROR
_ERRORCODE.fields_by_name['keyword_plan_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__error__pb2._KEYWORDPLANERRORENUM_KEYWORDPLANERROR
_ERRORCODE.fields_by_name['keyword_plan_campaign_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__campaign__error__pb2._KEYWORDPLANCAMPAIGNERRORENUM_KEYWORDPLANCAMPAIGNERROR
_ERRORCODE.fields_by_name['keyword_plan_negative_keyword_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__negative__keyword__error__pb2._KEYWORDPLANNEGATIVEKEYWORDERRORENUM_KEYWORDPLANNEGATIVEKEYWORDERROR
_ERRORCODE.fields_by_name['keyword_plan_ad_group_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__ad__group__error__pb2._KEYWORDPLANADGROUPERRORENUM_KEYWORDPLANADGROUPERROR
_ERRORCODE.fields_by_name['keyword_plan_keyword_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__keyword__error__pb2._KEYWORDPLANKEYWORDERRORENUM_KEYWORDPLANKEYWORDERROR
_ERRORCODE.fields_by_name['keyword_plan_idea_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_keyword__plan__idea__error__pb2._KEYWORDPLANIDEAERRORENUM_KEYWORDPLANIDEAERROR
_ERRORCODE.fields_by_name['account_budget_proposal_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_account__budget__proposal__error__pb2._ACCOUNTBUDGETPROPOSALERRORENUM_ACCOUNTBUDGETPROPOSALERROR
_ERRORCODE.fields_by_name['user_list_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_user__list__error__pb2._USERLISTERRORENUM_USERLISTERROR
_ERRORCODE.fields_by_name['change_status_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_change__status__error__pb2._CHANGESTATUSERRORENUM_CHANGESTATUSERROR
_ERRORCODE.fields_by_name['feed_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__error__pb2._FEEDERRORENUM_FEEDERROR
_ERRORCODE.fields_by_name['geo_target_constant_suggestion_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_geo__target__constant__suggestion__error__pb2._GEOTARGETCONSTANTSUGGESTIONERRORENUM_GEOTARGETCONSTANTSUGGESTIONERROR
_ERRORCODE.fields_by_name['campaign_draft_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__draft__error__pb2._CAMPAIGNDRAFTERRORENUM_CAMPAIGNDRAFTERROR
_ERRORCODE.fields_by_name['feed_item_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__error__pb2._FEEDITEMERRORENUM_FEEDITEMERROR
_ERRORCODE.fields_by_name['label_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_label__error__pb2._LABELERRORENUM_LABELERROR
_ERRORCODE.fields_by_name['billing_setup_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_billing__setup__error__pb2._BILLINGSETUPERRORENUM_BILLINGSETUPERROR
_ERRORCODE.fields_by_name['customer_client_link_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__client__link__error__pb2._CUSTOMERCLIENTLINKERRORENUM_CUSTOMERCLIENTLINKERROR
_ERRORCODE.fields_by_name['customer_manager_link_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__manager__link__error__pb2._CUSTOMERMANAGERLINKERRORENUM_CUSTOMERMANAGERLINKERROR
_ERRORCODE.fields_by_name['feed_mapping_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__mapping__error__pb2._FEEDMAPPINGERRORENUM_FEEDMAPPINGERROR
_ERRORCODE.fields_by_name['customer_feed_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_customer__feed__error__pb2._CUSTOMERFEEDERRORENUM_CUSTOMERFEEDERROR
_ERRORCODE.fields_by_name['ad_group_feed_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__group__feed__error__pb2._ADGROUPFEEDERRORENUM_ADGROUPFEEDERROR
_ERRORCODE.fields_by_name['campaign_feed_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__feed__error__pb2._CAMPAIGNFEEDERRORENUM_CAMPAIGNFEEDERROR
_ERRORCODE.fields_by_name['custom_interest_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_custom__interest__error__pb2._CUSTOMINTERESTERRORENUM_CUSTOMINTERESTERROR
_ERRORCODE.fields_by_name['campaign_experiment_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_campaign__experiment__error__pb2._CAMPAIGNEXPERIMENTERRORENUM_CAMPAIGNEXPERIMENTERROR
_ERRORCODE.fields_by_name['extension_feed_item_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_extension__feed__item__error__pb2._EXTENSIONFEEDITEMERRORENUM_EXTENSIONFEEDITEMERROR
_ERRORCODE.fields_by_name['ad_parameter_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_ad__parameter__error__pb2._ADPARAMETERERRORENUM_ADPARAMETERERROR
_ERRORCODE.fields_by_name['feed_item_validation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2._FEEDITEMVALIDATIONERRORENUM_FEEDITEMVALIDATIONERROR
_ERRORCODE.fields_by_name['extension_setting_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_extension__setting__error__pb2._EXTENSIONSETTINGERRORENUM_EXTENSIONSETTINGERROR
_ERRORCODE.fields_by_name['feed_item_target_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__target__error__pb2._FEEDITEMTARGETERRORENUM_FEEDITEMTARGETERROR
_ERRORCODE.fields_by_name['policy_violation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__violation__error__pb2._POLICYVIOLATIONERRORENUM_POLICYVIOLATIONERROR
_ERRORCODE.fields_by_name['mutate_job_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_mutate__job__error__pb2._MUTATEJOBERRORENUM_MUTATEJOBERROR
_ERRORCODE.fields_by_name['partial_failure_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_partial__failure__error__pb2._PARTIALFAILUREERRORENUM_PARTIALFAILUREERROR
_ERRORCODE.fields_by_name['policy_validation_parameter_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_policy__validation__parameter__error__pb2._POLICYVALIDATIONPARAMETERERRORENUM_POLICYVALIDATIONPARAMETERERROR
_ERRORCODE.fields_by_name['size_limit_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_size__limit__error__pb2._SIZELIMITERRORENUM_SIZELIMITERROR
_ERRORCODE.fields_by_name['not_whitelisted_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_not__whitelisted__error__pb2._NOTWHITELISTEDERRORENUM_NOTWHITELISTEDERROR
_ERRORCODE.fields_by_name['manager_link_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_manager__link__error__pb2._MANAGERLINKERRORENUM_MANAGERLINKERROR
_ERRORCODE.fields_by_name['currency_code_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_currency__code__error__pb2._CURRENCYCODEERRORENUM_CURRENCYCODEERROR
_ERRORCODE.fields_by_name['access_invitation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_access__invitation__error__pb2._ACCESSINVITATIONERRORENUM_ACCESSINVITATIONERROR
_ERRORCODE.fields_by_name['reach_plan_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_reach__plan__error__pb2._REACHPLANERRORENUM_REACHPLANERROR
_ERRORCODE.fields_by_name['invoice_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_invoice__error__pb2._INVOICEERRORENUM_INVOICEERROR
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['request_error'])
_ERRORCODE.fields_by_name['request_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['bidding_strategy_error'])
_ERRORCODE.fields_by_name['bidding_strategy_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['url_field_error'])
_ERRORCODE.fields_by_name['url_field_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['list_operation_error'])
_ERRORCODE.fields_by_name['list_operation_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['query_error'])
_ERRORCODE.fields_by_name['query_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['mutate_error'])
_ERRORCODE.fields_by_name['mutate_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['field_mask_error'])
_ERRORCODE.fields_by_name['field_mask_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['authorization_error'])
_ERRORCODE.fields_by_name['authorization_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['internal_error'])
_ERRORCODE.fields_by_name['internal_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['quota_error'])
_ERRORCODE.fields_by_name['quota_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_error'])
_ERRORCODE.fields_by_name['ad_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_group_error'])
_ERRORCODE.fields_by_name['ad_group_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['campaign_budget_error'])
_ERRORCODE.fields_by_name['campaign_budget_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['campaign_error'])
_ERRORCODE.fields_by_name['campaign_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['authentication_error'])
_ERRORCODE.fields_by_name['authentication_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_group_criterion_error'])
_ERRORCODE.fields_by_name['ad_group_criterion_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_customizer_error'])
_ERRORCODE.fields_by_name['ad_customizer_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_group_ad_error'])
_ERRORCODE.fields_by_name['ad_group_ad_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_sharing_error'])
_ERRORCODE.fields_by_name['ad_sharing_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['adx_error'])
_ERRORCODE.fields_by_name['adx_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['asset_error'])
_ERRORCODE.fields_by_name['asset_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['bidding_error'])
_ERRORCODE.fields_by_name['bidding_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['campaign_criterion_error'])
_ERRORCODE.fields_by_name['campaign_criterion_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['collection_size_error'])
_ERRORCODE.fields_by_name['collection_size_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['country_code_error'])
_ERRORCODE.fields_by_name['country_code_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['criterion_error'])
_ERRORCODE.fields_by_name['criterion_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['customer_error'])
_ERRORCODE.fields_by_name['customer_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['date_error'])
_ERRORCODE.fields_by_name['date_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['date_range_error'])
_ERRORCODE.fields_by_name['date_range_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['distinct_error'])
_ERRORCODE.fields_by_name['distinct_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['feed_attribute_reference_error'])
_ERRORCODE.fields_by_name['feed_attribute_reference_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['function_error'])
_ERRORCODE.fields_by_name['function_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['function_parsing_error'])
_ERRORCODE.fields_by_name['function_parsing_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['id_error'])
_ERRORCODE.fields_by_name['id_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['image_error'])
_ERRORCODE.fields_by_name['image_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['language_code_error'])
_ERRORCODE.fields_by_name['language_code_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['media_bundle_error'])
_ERRORCODE.fields_by_name['media_bundle_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['media_upload_error'])
_ERRORCODE.fields_by_name['media_upload_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['media_file_error'])
_ERRORCODE.fields_by_name['media_file_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['multiplier_error'])
_ERRORCODE.fields_by_name['multiplier_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['new_resource_creation_error'])
_ERRORCODE.fields_by_name['new_resource_creation_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['not_empty_error'])
_ERRORCODE.fields_by_name['not_empty_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['null_error'])
_ERRORCODE.fields_by_name['null_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['operator_error'])
_ERRORCODE.fields_by_name['operator_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['range_error'])
_ERRORCODE.fields_by_name['range_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['recommendation_error'])
_ERRORCODE.fields_by_name['recommendation_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['region_code_error'])
_ERRORCODE.fields_by_name['region_code_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['setting_error'])
_ERRORCODE.fields_by_name['setting_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['string_format_error'])
_ERRORCODE.fields_by_name['string_format_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['string_length_error'])
_ERRORCODE.fields_by_name['string_length_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['operation_access_denied_error'])
_ERRORCODE.fields_by_name['operation_access_denied_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['resource_access_denied_error'])
_ERRORCODE.fields_by_name['resource_access_denied_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['resource_count_limit_exceeded_error'])
_ERRORCODE.fields_by_name['resource_count_limit_exceeded_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['youtube_video_registration_error'])
_ERRORCODE.fields_by_name['youtube_video_registration_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_group_bid_modifier_error'])
_ERRORCODE.fields_by_name['ad_group_bid_modifier_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['context_error'])
_ERRORCODE.fields_by_name['context_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['field_error'])
_ERRORCODE.fields_by_name['field_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['shared_set_error'])
_ERRORCODE.fields_by_name['shared_set_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['shared_criterion_error'])
_ERRORCODE.fields_by_name['shared_criterion_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['campaign_shared_set_error'])
_ERRORCODE.fields_by_name['campaign_shared_set_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['conversion_action_error'])
_ERRORCODE.fields_by_name['conversion_action_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['conversion_adjustment_upload_error'])
_ERRORCODE.fields_by_name['conversion_adjustment_upload_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['conversion_upload_error'])
_ERRORCODE.fields_by_name['conversion_upload_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['header_error'])
_ERRORCODE.fields_by_name['header_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['database_error'])
_ERRORCODE.fields_by_name['database_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['policy_finding_error'])
_ERRORCODE.fields_by_name['policy_finding_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['enum_error'])
_ERRORCODE.fields_by_name['enum_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['keyword_plan_error'])
_ERRORCODE.fields_by_name['keyword_plan_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['keyword_plan_campaign_error'])
_ERRORCODE.fields_by_name['keyword_plan_campaign_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['keyword_plan_negative_keyword_error'])
_ERRORCODE.fields_by_name['keyword_plan_negative_keyword_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['keyword_plan_ad_group_error'])
_ERRORCODE.fields_by_name['keyword_plan_ad_group_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['keyword_plan_keyword_error'])
_ERRORCODE.fields_by_name['keyword_plan_keyword_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['keyword_plan_idea_error'])
_ERRORCODE.fields_by_name['keyword_plan_idea_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['account_budget_proposal_error'])
_ERRORCODE.fields_by_name['account_budget_proposal_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['user_list_error'])
_ERRORCODE.fields_by_name['user_list_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['change_status_error'])
_ERRORCODE.fields_by_name['change_status_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['feed_error'])
_ERRORCODE.fields_by_name['feed_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['geo_target_constant_suggestion_error'])
_ERRORCODE.fields_by_name['geo_target_constant_suggestion_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['campaign_draft_error'])
_ERRORCODE.fields_by_name['campaign_draft_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['feed_item_error'])
_ERRORCODE.fields_by_name['feed_item_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['label_error'])
_ERRORCODE.fields_by_name['label_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['billing_setup_error'])
_ERRORCODE.fields_by_name['billing_setup_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['customer_client_link_error'])
_ERRORCODE.fields_by_name['customer_client_link_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['customer_manager_link_error'])
_ERRORCODE.fields_by_name['customer_manager_link_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['feed_mapping_error'])
_ERRORCODE.fields_by_name['feed_mapping_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['customer_feed_error'])
_ERRORCODE.fields_by_name['customer_feed_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_group_feed_error'])
_ERRORCODE.fields_by_name['ad_group_feed_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['campaign_feed_error'])
_ERRORCODE.fields_by_name['campaign_feed_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['custom_interest_error'])
_ERRORCODE.fields_by_name['custom_interest_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['campaign_experiment_error'])
_ERRORCODE.fields_by_name['campaign_experiment_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['extension_feed_item_error'])
_ERRORCODE.fields_by_name['extension_feed_item_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['ad_parameter_error'])
_ERRORCODE.fields_by_name['ad_parameter_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['feed_item_validation_error'])
_ERRORCODE.fields_by_name['feed_item_validation_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['extension_setting_error'])
_ERRORCODE.fields_by_name['extension_setting_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['feed_item_target_error'])
_ERRORCODE.fields_by_name['feed_item_target_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['policy_violation_error'])
_ERRORCODE.fields_by_name['policy_violation_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['mutate_job_error'])
_ERRORCODE.fields_by_name['mutate_job_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['partial_failure_error'])
_ERRORCODE.fields_by_name['partial_failure_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['policy_validation_parameter_error'])
_ERRORCODE.fields_by_name['policy_validation_parameter_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['size_limit_error'])
_ERRORCODE.fields_by_name['size_limit_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['not_whitelisted_error'])
_ERRORCODE.fields_by_name['not_whitelisted_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['manager_link_error'])
_ERRORCODE.fields_by_name['manager_link_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['currency_code_error'])
_ERRORCODE.fields_by_name['currency_code_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['access_invitation_error'])
_ERRORCODE.fields_by_name['access_invitation_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['reach_plan_error'])
_ERRORCODE.fields_by_name['reach_plan_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORCODE.oneofs_by_name['error_code'].fields.append(
  _ERRORCODE.fields_by_name['invoice_error'])
_ERRORCODE.fields_by_name['invoice_error'].containing_oneof = _ERRORCODE.oneofs_by_name['error_code']
_ERRORLOCATION_FIELDPATHELEMENT.fields_by_name['index'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ERRORLOCATION_FIELDPATHELEMENT.containing_type = _ERRORLOCATION
_ERRORLOCATION.fields_by_name['field_path_elements'].message_type = _ERRORLOCATION_FIELDPATHELEMENT
_ERRORDETAILS.fields_by_name['policy_violation_details'].message_type = _POLICYVIOLATIONDETAILS
_ERRORDETAILS.fields_by_name['policy_finding_details'].message_type = _POLICYFINDINGDETAILS
_POLICYVIOLATIONDETAILS.fields_by_name['key'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2._POLICYVIOLATIONKEY
_POLICYFINDINGDETAILS.fields_by_name['policy_topic_entries'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2._POLICYTOPICENTRY
DESCRIPTOR.message_types_by_name['GoogleAdsFailure'] = _GOOGLEADSFAILURE
DESCRIPTOR.message_types_by_name['GoogleAdsError'] = _GOOGLEADSERROR
DESCRIPTOR.message_types_by_name['ErrorCode'] = _ERRORCODE
DESCRIPTOR.message_types_by_name['ErrorLocation'] = _ERRORLOCATION
DESCRIPTOR.message_types_by_name['ErrorDetails'] = _ERRORDETAILS
DESCRIPTOR.message_types_by_name['PolicyViolationDetails'] = _POLICYVIOLATIONDETAILS
DESCRIPTOR.message_types_by_name['PolicyFindingDetails'] = _POLICYFINDINGDETAILS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GoogleAdsFailure = _reflection.GeneratedProtocolMessageType('GoogleAdsFailure', (_message.Message,), dict(
  DESCRIPTOR = _GOOGLEADSFAILURE,
  __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
  ,
  __doc__ = """Describes how a GoogleAds API call failed. It's returned inside
  google.rpc.Status.details when a call fails.
  
  
  Attributes:
      errors:
          The list of errors that occurred.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.GoogleAdsFailure)
  ))
_sym_db.RegisterMessage(GoogleAdsFailure)

GoogleAdsError = _reflection.GeneratedProtocolMessageType('GoogleAdsError', (_message.Message,), dict(
  DESCRIPTOR = _GOOGLEADSERROR,
  __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
  ,
  __doc__ = """GoogleAds-specific error.
  
  
  Attributes:
      error_code:
          An enum value that indicates which error occurred.
      message:
          A human-readable description of the error.
      trigger:
          The value that triggered the error.
      location:
          Describes the part of the request proto that caused the error.
      details:
          Additional error details, which are returned by certain error
          codes. Most error codes do not include details.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.GoogleAdsError)
  ))
_sym_db.RegisterMessage(GoogleAdsError)

ErrorCode = _reflection.GeneratedProtocolMessageType('ErrorCode', (_message.Message,), dict(
  DESCRIPTOR = _ERRORCODE,
  __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
  ,
  __doc__ = """The error reason represented by type and enum.
  
  
  Attributes:
      error_code:
          The list of error enums
      request_error:
          An error caused by the request
      bidding_strategy_error:
          An error with a Bidding Strategy mutate.
      url_field_error:
          An error with a URL field mutate.
      list_operation_error:
          An error with a list operation.
      query_error:
          An error with an AWQL query
      mutate_error:
          An error with a mutate
      field_mask_error:
          An error with a field mask
      authorization_error:
          An error encountered when trying to authorize a user.
      internal_error:
          An unexpected server-side error.
      quota_error:
          An error with the amonut of quota remaining.
      ad_error:
          An error with an Ad Group Ad mutate.
      ad_group_error:
          An error with an Ad Group mutate.
      campaign_budget_error:
          An error with a Campaign Budget mutate.
      campaign_error:
          An error with a Campaign mutate.
      authentication_error:
          Indicates failure to properly authenticate user.
      ad_group_criterion_error:
          Indicates failure to properly authenticate user.
      ad_customizer_error:
          The reasons for the ad customizer error
      ad_group_ad_error:
          The reasons for the ad group ad error
      ad_sharing_error:
          The reasons for the ad sharing error
      adx_error:
          The reasons for the adx error
      asset_error:
          The reasons for the asset error
      bidding_error:
          The reasons for the bidding errors
      campaign_criterion_error:
          The reasons for the campaign criterion error
      collection_size_error:
          The reasons for the collection size error
      country_code_error:
          The reasons for the country code error
      criterion_error:
          The reasons for the criterion error
      customer_error:
          The reasons for the customer error
      date_error:
          The reasons for the date error
      date_range_error:
          The reasons for the date range error
      distinct_error:
          The reasons for the distinct error
      feed_attribute_reference_error:
          The reasons for the feed attribute reference error
      function_error:
          The reasons for the function error
      function_parsing_error:
          The reasons for the function parsing error
      id_error:
          The reasons for the id error
      image_error:
          The reasons for the image error
      language_code_error:
          The reasons for the language code error
      media_bundle_error:
          The reasons for the media bundle error
      media_upload_error:
          The reasons for media uploading errors.
      media_file_error:
          The reasons for the media file error
      multiplier_error:
          The reasons for the multiplier error
      new_resource_creation_error:
          The reasons for the new resource creation error
      not_empty_error:
          The reasons for the not empty error
      null_error:
          The reasons for the null error
      operator_error:
          The reasons for the operator error
      range_error:
          The reasons for the range error
      recommendation_error:
          The reasons for error in applying a recommendation
      region_code_error:
          The reasons for the region code error
      setting_error:
          The reasons for the setting error
      string_format_error:
          The reasons for the string format error
      string_length_error:
          The reasons for the string length error
      operation_access_denied_error:
          The reasons for the operation access denied error
      resource_access_denied_error:
          The reasons for the resource access denied error
      resource_count_limit_exceeded_error:
          The reasons for the resource count limit exceeded error
      youtube_video_registration_error:
          The reasons for YouTube video registration errors.
      ad_group_bid_modifier_error:
          The reasons for the ad group bid modifier error
      context_error:
          The reasons for the context error
      field_error:
          The reasons for the field error
      shared_set_error:
          The reasons for the shared set error
      shared_criterion_error:
          The reasons for the shared criterion error
      campaign_shared_set_error:
          The reasons for the campaign shared set error
      conversion_action_error:
          The reasons for the conversion action error
      conversion_adjustment_upload_error:
          The reasons for the conversion adjustment upload error
      conversion_upload_error:
          The reasons for the conversion upload error
      header_error:
          The reasons for the header error.
      database_error:
          The reasons for the database error.
      policy_finding_error:
          The reasons for the policy finding error.
      enum_error:
          The reason for enum error.
      keyword_plan_error:
          The reason for keyword plan error.
      keyword_plan_campaign_error:
          The reason for keyword plan campaign error.
      keyword_plan_negative_keyword_error:
          The reason for keyword plan negative keyword error.
      keyword_plan_ad_group_error:
          The reason for keyword plan ad group error.
      keyword_plan_keyword_error:
          The reason for keyword plan keyword error.
      keyword_plan_idea_error:
          The reason for keyword idea error.
      account_budget_proposal_error:
          The reasons for account budget proposal errors.
      user_list_error:
          The reasons for the user list error
      change_status_error:
          The reasons for the change status error
      feed_error:
          The reasons for the feed error
      geo_target_constant_suggestion_error:
          The reasons for the geo target constant suggestion error.
      campaign_draft_error:
          The reasons for the campaign draft error
      feed_item_error:
          The reasons for the feed item error
      label_error:
          The reason for the label error.
      billing_setup_error:
          The reasons for the billing setup error
      customer_client_link_error:
          The reasons for the customer client link error
      customer_manager_link_error:
          The reasons for the customer manager link error
      feed_mapping_error:
          The reasons for the feed mapping error
      customer_feed_error:
          The reasons for the customer feed error
      ad_group_feed_error:
          The reasons for the ad group feed error
      campaign_feed_error:
          The reasons for the campaign feed error
      custom_interest_error:
          The reasons for the custom interest error
      campaign_experiment_error:
          The reasons for the campaign experiment error
      extension_feed_item_error:
          The reasons for the extension feed item error
      ad_parameter_error:
          The reasons for the ad parameter error
      feed_item_validation_error:
          The reasons for the feed item validation error
      extension_setting_error:
          The reasons for the extension setting error
      feed_item_target_error:
          The reasons for the feed item target error
      policy_violation_error:
          The reasons for the policy violation error
      mutate_job_error:
          The reasons for the mutate job error
      partial_failure_error:
          The reasons for the mutate job error
      policy_validation_parameter_error:
          The reasons for the policy validation parameter error
      size_limit_error:
          The reasons for the size limit error
      not_whitelisted_error:
          The reasons for the not whitelisted error
      manager_link_error:
          The reasons for the manager link error
      currency_code_error:
          The reasons for the currency code error
      access_invitation_error:
          The reasons for the access invitation error
      reach_plan_error:
          The reasons for the reach plan error
      invoice_error:
          The reasons for the invoice error
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.ErrorCode)
  ))
_sym_db.RegisterMessage(ErrorCode)

ErrorLocation = _reflection.GeneratedProtocolMessageType('ErrorLocation', (_message.Message,), dict(

  FieldPathElement = _reflection.GeneratedProtocolMessageType('FieldPathElement', (_message.Message,), dict(
    DESCRIPTOR = _ERRORLOCATION_FIELDPATHELEMENT,
    __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
    ,
    __doc__ = """A part of a field path.
    
    
    Attributes:
        field_name:
            The name of a field or a oneof
        index:
            If field\_name is a repeated field, this is the element that
            failed
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.ErrorLocation.FieldPathElement)
    ))
  ,
  DESCRIPTOR = _ERRORLOCATION,
  __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
  ,
  __doc__ = """Describes the part of the request proto that caused the error.
  
  
  Attributes:
      field_path_elements:
          A field path that indicates which field was invalid in the
          request.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.ErrorLocation)
  ))
_sym_db.RegisterMessage(ErrorLocation)
_sym_db.RegisterMessage(ErrorLocation.FieldPathElement)

ErrorDetails = _reflection.GeneratedProtocolMessageType('ErrorDetails', (_message.Message,), dict(
  DESCRIPTOR = _ERRORDETAILS,
  __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
  ,
  __doc__ = """Additional error details.
  
  
  Attributes:
      unpublished_error_code:
          The error code that should have been returned, but wasn't.
          This is used when the error code is
          InternalError.ERROR\_CODE\_NOT\_PUBLISHED.
      policy_violation_details:
          Describes an ad policy violation.
      policy_finding_details:
          Describes policy violation findings.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.ErrorDetails)
  ))
_sym_db.RegisterMessage(ErrorDetails)

PolicyViolationDetails = _reflection.GeneratedProtocolMessageType('PolicyViolationDetails', (_message.Message,), dict(
  DESCRIPTOR = _POLICYVIOLATIONDETAILS,
  __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
  ,
  __doc__ = """Error returned as part of a mutate response. This error indicates single
  policy violation by some text in one of the fields.
  
  
  Attributes:
      external_policy_description:
          Human readable description of policy violation.
      key:
          Unique identifier for this violation. If policy is exemptible,
          this key may be used to request exemption.
      external_policy_name:
          Human readable name of the policy.
      is_exemptible:
          Whether user can file an exemption request for this violation.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.PolicyViolationDetails)
  ))
_sym_db.RegisterMessage(PolicyViolationDetails)

PolicyFindingDetails = _reflection.GeneratedProtocolMessageType('PolicyFindingDetails', (_message.Message,), dict(
  DESCRIPTOR = _POLICYFINDINGDETAILS,
  __module__ = 'google.ads.googleads_v2.proto.errors.errors_pb2'
  ,
  __doc__ = """Error returned as part of a mutate response. This error indicates one or
  more policy findings in the fields of a resource.
  
  
  Attributes:
      policy_topic_entries:
          The list of policy topics for the resource. Contains the
          PROHIBITED or FULLY\_LIMITED policy topic entries that
          prevented the resource from being saved (among any other
          entries the resource may also have).
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.PolicyFindingDetails)
  ))
_sym_db.RegisterMessage(PolicyFindingDetails)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
